/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		8-Bit-Analog-Digital-Converter mit ATMEL ATmega8 to STK500 board, output on (PortB) --> LEDs 

Description: 	The ADC converts an analog input voltage to a 10-bit digital value through successive 
				approximation. The minimum value represents GND and the maximum value represents the 
				voltage on the AREF

Author: 		Peniely Lydos

AppNote:        AVR500 - ADC implementation

Datum: 			26/05/2009

Version: 		0.0

File Name: 		ADC_USART_Init_Read_adc.c

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//----------------------------------------------------------------------------------------------------------------
//ADC Multiplexer Selecter Register (ADMUX)
//----------------------------------------------------------------------------------------------------------------
//REFS1		REFS0		ADLAR		-		MUX3	MUX2	MUX1	MUX0
//voltage reference for the ADC
//REFS1	REFS0	Wert
//  0	  0		AREF, Internal Vref turned off
//  0	  1		AVCC with external capacitor at AREF pin
//  1	  0		Reserved
//  1	  1		Internal 2.56V Voltage Reference with external capacitor at AREF pin
//						  1=> to left adjust the result
//						  0=> the result is right adjusted
//											{-Analog Channel Selection bits-}
//											0		0		0		0	ADC0	
//											0		0		0		1	ADC1
//											0		0		1		0	ADC2
//											0		0		1		1	ADC3
//											0		1		0		0	ADC4
//											0		1		0		1	ADC5
//											0		1		1		0	ADC6
//											0		1		1		1	ADC7
//----------------------------------------------------------------------------------------------------------------
//Externe Refferenzspannung;Ergebniss Recht und Kanal ADC0
//----------------------------------------------------------------------------------------------------------------
//ADC Controll und STATUS REGISTER A (ADCSRA)
//----------------------------------------------------------------------------------------------------------------
//  ADEN	ADSC	ADFR	ADIF	  ADIE	   ADPS2	ADPS1	   ADPS0
//1=>Writing this bit to one enables the ADC
//			1=>In Single Conversion mode, start each conversion. In Free Running mode start the first conversion.
//					1=>the ADC operates in Free Running mode
//							"1/0" 	=>STATUS will be set from Conversion whenn new Result in memory
//									"1/0"  => Status whenn I-Flag (SFR) und ADIE setting star the ADC routine
//											  {" ADC Prescaler Select Bits"} Division Factor
//												0		  0	  		0			2
//  											0		  0	  		1			2
//  											0		  1	  		0			4
//  										  	0		  1	  		1			8
//  										  	1 		  0	  		0			16
//  										  	1		  0	  		1			32		
//  										  	1		  1	  		0			64
//  										  	1		  1	  		1			128
//The ADC requires an input clock frequency between 50 kHz and 200 kHz to get maximum resolution.
//TF_min=CLK/200000
//TF_max=CLK/50000 


#include <inttypes.h>

//----------------------------------------------------------
// ADC Functions
//----------------------------------------------------------

void init(void);

uint16_t ADC_Read(uint8_t Mux_channel);
